14
15
16
17
18
19
20
21
22
23
24
25
26
|
# File 'lib/active_record_caching/errors.rb', line 14
def message
"ActiveModel::Serializer implementation check required."\
"\n\n" \
"There were some discrepancies found in regards to serialization\n" \
"caching with ActiveModel::Serializer > 0.8.1.\n\n" \
"Since it appears that ASM has been upgraded, you must double\n" \
"check that ASM does indeed support caching and ensure that the\n" \
"patches in CacheSerializing are still needed and compatible.\n\n" \
"For more information:\n\n" \
" * https://github.com/rails-api/active_model_serializers/issues/467#issuecomment-30388385\n" \
" * https://github.com/rails-api/active_model_serializers/issues/478#issuecomment-31367143\n" \
"\n\n"
end
|